@@ -1,8 +1,8 @@
 use crate::color::to_ansi;
-use crate::config::Style;
 use crate::highlight_utils;
 use crate::highlighters::HighlightFn;
 use crate::line_info::LineInfo;
+use crate::theme::Style;
 use lazy_static::lazy_static;
 use regex::Regex;
 
